==> db4o_6.1.401~dfsg.orig.tar.gz: db4o-6.1/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Soda/AllTests.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Soda
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		protected override System.Type[] TestCases()
		{
			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.AllTests)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.CollectionIndexedJoinTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STBooleanTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STBooleanWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STByteTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STByteWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STCharWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STDoubleTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STDoubleWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STETH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STFloatTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STFloatWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STIntegerTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STLongTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STLongWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Joins.Typed.STOrTTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerWTTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STSDFT1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STShortTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STShortWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STStringUTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STTH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STUH1TestCase)
				 };
		}

		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Soda.AllTests().RunSolo();
		}
	}
}

==> db4o_6.1.604+dfsg.orig.tar.gz: db4o-6.1.604/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Soda/AllTests.cs <==
/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Soda
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		protected override System.Type[] TestCases()
		{
			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.AllTests)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.CollectionIndexedJoinTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.NullIdentityConstraintTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STBooleanTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STBooleanWUTestCase), 
				typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STByteTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STByteWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STCharWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STDoubleTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STDoubleWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STETH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STFloatTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STFloatWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STIntegerTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STLongTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STLongWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Joins.Typed.STOrTTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerWTTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STSDFT1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STShortTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STShortWUTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STStringUTestCase), typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STTH1TestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STUH1TestCase)
				 };
		}

		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Soda.AllTests().RunSolo();
		}
	}
}
